@@ -1113,6 +1113,7 @@ option_t<report_t> * report_t::lookup_option(const char * p)
     OPT(csv_format_);
     else OPT_ALT(gain, change);
     else OPT(cleared);
+    else OPT(cleared_format_);
     else OPT(collapse);
     else OPT(collapse_if_zero);
     else OPT(color);
@@ -1189,6 +1190,7 @@ option_t<report_t> * report_t::lookup_option(const char * p)
   case 'n':
     OPT_CH(collapse);
     else OPT(no_color);
+    else OPT(no_pager);
     else OPT(no_rounding);
     else OPT(no_titles);
     else OPT(no_total);
