@@ -302,6 +302,7 @@ public:
     HANDLER(market).report(out);
     HANDLER(meta_).report(out);
     HANDLER(monthly).report(out);
+    HANDLER(no_pager).report(out);
     HANDLER(no_rounding).report(out);
     HANDLER(no_titles).report(out);
     HANDLER(no_total).report(out);
@@ -464,8 +465,8 @@ public:
        "           12 + 1 + 12 + 1 + 12, true, color))"
        " %(ansify_if("
        "   justify((get_at(display_total, 1) ? "
-       "            (100% * scrub(get_at(display_total, 0))) / "
-       "             -scrub(get_at(display_total, 1)) : 0), "
+       "            (100% * quantity(scrub(get_at(display_total, 0)))) / "
+       "             -quantity(scrub(get_at(display_total, 1))) : 0), "
        "           5, -1, true, false),"
        "   magenta if (color and get_at(display_total, 1) and "
        "               (abs(quantity(scrub(get_at(display_total, 0))) / "
