@@ -77,16 +77,18 @@ namespace {
     std::istream&            in;
     instance_t *             parent;
     std::list<application_t> apply_stack;
+    bool                     no_assertions;
 #if defined(TIMELOG_SUPPORT)
     time_log_t               timelog;
 #endif
 
     instance_t(parse_context_stack_t& _context_stack,
                parse_context_t&       _context,
-               instance_t *           _parent = NULL)
+               instance_t *           _parent = NULL,
+               const bool             _no_assertions = false)
       : context_stack(_context_stack), context(_context),
         in(*context.stream.get()), parent(_parent),
-        timelog(context) {}
+        no_assertions(_no_assertions), timelog(context) {}
 
     virtual string description() {
       return _("textual parser");
@@ -153,6 +155,7 @@ namespace {
 
     void payee_directive(char * line);
     void payee_alias_directive(const string& payee, string alias);
+    void payee_uuid_directive(const string& payee, string uuid);
 
     void commodity_directive(char * line);
     void commodity_alias_directive(commodity_t& comm, string alias);
@@ -779,8 +782,8 @@ void instance_t::include_directive(char * line)
           context_stack.get_current().master  = master;
           context_stack.get_current().scope   = scope;
           try {
-            instance_t instance(context_stack,
-                                context_stack.get_current(), this);
+            instance_t instance(context_stack, context_stack.get_current(),
+                                this, no_assertions);
             instance.apply_stack.push_front(application_t("account", master));
             instance.parse();
           }
@@ -915,6 +918,10 @@ void instance_t::account_directive(char * line)
 
     char * b = next_element(q);
     string keyword(q);
+    // Ensure there's an argument for the directives that need one.
+    if (! b && keyword != "default")
+      throw_(parse_error, _f("Account directive '%1%' requires an argument") % keyword);
+
     if (keyword == "alias") {
       account_alias_directive(account, b);
     }
@@ -1031,16 +1038,28 @@ void instance_t::payee_directive(char * line)
 
     char * b = next_element(p);
     string keyword(p);
+    if (! b)
+      throw_(parse_error, _f("Payee directive '%1%' requires an argument") % keyword);
+
     if (keyword == "alias")
       payee_alias_directive(payee, b);
+    if (keyword == "uuid")
+      payee_uuid_directive(payee, b);
   }
 }
 
 void instance_t::payee_alias_directive(const string& payee, string alias)
 {
   trim(alias);
-  context.journal->payee_mappings
-    .push_back(payee_mapping_t(mask_t(alias), payee));
+  context.journal->payee_alias_mappings
+    .push_back(payee_alias_mapping_t(mask_t(alias), payee));
+}
+
+void instance_t::payee_uuid_directive(const string& payee, string uuid)
+{
+  trim(uuid);
+  context.journal->payee_uuid_mappings
+    .push_back(payee_uuid_mapping_t(uuid, payee));
 }
 
 void instance_t::commodity_directive(char * line)
@@ -1061,6 +1080,10 @@ void instance_t::commodity_directive(char * line)
 
       char * b = next_element(q);
       string keyword(q);
+      // Ensure there's an argument for the directives that need one.
+      if (! b && keyword != "nomarket" && keyword != "default")
+        throw_(parse_error, _f("Commodity directive '%1%' requires an argument") % keyword);
+
       if (keyword == "alias")
         commodity_alias_directive(*commodity, b);
       else if (keyword == "value")
@@ -1245,6 +1268,14 @@ bool instance_t::general_directive(char * line)
   if (*p == '@' || *p == '!')
     p++;
 
+  // Ensure there's an argument for all directives that need one.
+  if (! arg &&
+      std::strcmp(p, "comment") != 0 && std::strcmp(p, "end") != 0
+      && std::strcmp(p, "python") != 0 && std::strcmp(p, "test") != 0 &&
+      *p != 'Y') {
+    throw_(parse_error, _f("Directive '%1%' requires an argument") % p);
+  }
+
   switch (*p) {
   case 'a':
     if (std::strcmp(p, "account") == 0) {
@@ -1403,8 +1434,7 @@ post_t * instance_t::parse_post(char *          line,
   }
 
   if (xact &&
-      ((xact->_state == item_t::CLEARED && post->_state != item_t::CLEARED) ||
-       (xact->_state == item_t::PENDING && post->_state == item_t::UNCLEARED)))
+      (xact->_state != item_t::UNCLEARED && post->_state == item_t::UNCLEARED))
     post->set_state(xact->_state);
 
   // Parse the account name
@@ -1430,6 +1460,12 @@ post_t * instance_t::parse_post(char *          line,
     }
     p++; e--;
   }
+  else if (*p == '<' && *(e - 1) == '>') {
+    post->add_flags(POST_DEFERRED);
+    DEBUG("textual.parse", "line " << context.linenum << ": "
+          << "Parsed a deferred account name");
+    p++; e--;
+  }
 
   string name(p, static_cast<string::size_type>(e - p));
   DEBUG("textual.parse", "line " << context.linenum << ": "
@@ -1495,13 +1531,12 @@ post_t * instance_t::parse_post(char *          line,
           post->add_flags(POST_COST_IN_FULL);
           DEBUG("textual.parse", "line " << context.linenum << ": "
                 << "And it's for a total price");
+          next++;
         }
 
-        if (post->has_flags(POST_COST_VIRTUAL) && *(next + 1) == ')')
+        if (post->has_flags(POST_COST_VIRTUAL) && *next == ')')
           ++next;
 
-        beg = static_cast<std::streamsize>(++next - line);
-
         p = skip_ws(next);
         if (*p) {
           post->cost = amount_t();
@@ -1543,6 +1578,8 @@ post_t * instance_t::parse_post(char *          line,
           if (fixed_cost)
             post->add_flags(POST_COST_FIXATED);
 
+          post->given_cost = post->cost;
+
           DEBUG("textual.parse", "line " << context.linenum << ": "
                 << "Total cost is " << *post->cost);
           DEBUG("textual.parse", "line " << context.linenum << ": "
@@ -1617,6 +1654,8 @@ post_t * instance_t::parse_post(char *          line,
         break;
       }
 
+      amount_t tot = amt - diff;
+
       DEBUG("post.assign",
             "line " << context.linenum << ": " << "diff = " << diff);
       DEBUG("textual.parse", "line " << context.linenum << ": "
@@ -1625,8 +1664,10 @@ post_t * instance_t::parse_post(char *          line,
       if (! diff.is_zero()) {
         if (! post->amount.is_null()) {
           diff -= post->amount;
-          if (! diff.is_zero())
-            throw_(parse_error, _f("Balance assertion off by %1%") % diff);
+          if (! no_assertions && ! diff.is_zero())
+            throw_(parse_error,
+                   _f("Balance assertion off by %1% (expected to see %2%)")
+                   % diff % tot);
         } else {
           post->amount = diff;
           DEBUG("textual.parse", "line " << context.linenum << ": "
@@ -1849,6 +1890,17 @@ xact_t * instance_t::parse_xact(char *          line,
     else {
       reveal_context = false;
 
+      if (!last_post) {
+        if (xact->has_tag(_("UUID"))) {
+          string uuid = xact->get_tag(_("UUID"))->to_string();
+          foreach (payee_uuid_mapping_t value, context.journal->payee_uuid_mappings) {
+            if (value.first.compare(uuid) == 0) {
+              xact->payee = value.second;
+            }
+          }
+        }
+      }
+
       if (post_t * post =
           parse_post(p, len - (p - line), account, xact.get())) {
         reveal_context = true;
@@ -1909,13 +1961,17 @@ std::size_t journal_t::read_textual(parse_context_stack_t& context_stack)
 {
   TRACE_START(parsing_total, 1, "Total time spent parsing text:");
   {
-    instance_t instance(context_stack, context_stack.get_current());
+    instance_t instance(context_stack, context_stack.get_current(), NULL,
+                        checking_style == journal_t::CHECK_PERMISSIVE);
     instance.apply_stack.push_front
       (application_t("account", context_stack.get_current().master));
     instance.parse();
   }
   TRACE_STOP(parsing_total, 1);
 
+  // Apply any deferred postings at this time
+  master->apply_deferred_posts();
+
   // These tracers were started in textual.cc
   TRACE_FINISH(xact_text, 1);
   TRACE_FINISH(xact_details, 1);
