@@ -839,6 +839,16 @@ void date_parser_t::determine_when(date_parser_t::lexer_t::token_t& tok,
     specifier.month =
       date_specifier_t::month_type
         (boost::get<date_time::months_of_year>(*tok.value));
+    tok = lexer.peek_token();
+    switch (tok.kind) {
+    case lexer_t::token_t::TOK_A_YEAR:
+      specifier.year = boost::get<date_specifier_t::year_type>(*tok.value);
+      break;
+    case lexer_t::token_t::END_REACHED:
+      break;
+    default:
+      break;
+    }
     break;
   case lexer_t::token_t::TOK_A_WDAY:
     specifier.wday  =
@@ -1802,6 +1812,7 @@ void times_initialize()
     readers.push_back(shared_ptr<date_io_t>(new date_io_t("%Y/%m/%d", true)));
     readers.push_back(shared_ptr<date_io_t>(new date_io_t("%Y/%m", true)));
     readers.push_back(shared_ptr<date_io_t>(new date_io_t("%y/%m/%d", true)));
+    readers.push_back(shared_ptr<date_io_t>(new date_io_t("%Y-%m-%d", true)));
 
     is_initialized = true;
   }
