@@ -568,7 +568,11 @@ public:
   void   stabilize(const optional<date_t>& date = none);
 
   bool   is_valid() const {
+#if BOOST_VERSION >= 105600
+    return start != NULL;
+#else
     return start;
+#endif
   }
 
   /** Find the current or next period containing date.  Returns false if
